@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 __license__ = 'GPL 3'
 __copyright__ = '2010, Hiroshi Miura <miurahr@linux.com>'
 __docformat__ = 'restructuredtext en'
@@ -20,20 +18,20 @@ Tranliterate the string from unicode characters to ASCII in Chinese and others.
 import unicodedata
 
 
-class Unihandecoder(object):
+class Unihandecoder:
     preferred_encoding = None
     decoder = None
 
     def __init__(self, lang="zh", encoding='utf-8'):
         self.preferred_encoding = encoding
         lang = lang.lower()
-        if lang[:2] == u'ja':
+        if lang[:2] == 'ja':
             from calibre.ebooks.unihandecode.jadecoder import Jadecoder
             self.decoder = Jadecoder()
-        elif lang[:2] == u'kr' or lang == u'korean':
+        elif lang[:2] == 'kr' or lang == 'korean':
             from calibre.ebooks.unihandecode.krdecoder import Krdecoder
             self.decoder = Krdecoder()
-        elif lang[:2] == u'vn' or lang == u'vietnum':
+        elif lang[:2] == 'vn' or lang == 'vietnum':
             from calibre.ebooks.unihandecode.vndecoder import Vndecoder
             self.decoder = Vndecoder()
         else:  # zh and others
@@ -41,18 +39,11 @@ class Unihandecoder(object):
             self.decoder = Unidecoder()
 
     def decode(self, text):
-        try:
-            unicode  # python2
-            if not isinstance(text, unicode):
-                try:
-                    text = unicode(text)
-                except:
-                    try:
-                        text = text.decode(self.preferred_encoding)
-                    except:
-                        text = text.decode('utf-8', 'replace')
-        except:  # python3, str is unicode
-            pass
+        if isinstance(text, bytes):
+            try:
+                text = text.decode(self.preferred_encoding)
+            except Exception:
+                text = text.decode('utf-8', 'replace')
         # at first unicode normalize it. (see Unicode standards)
         ntext = unicodedata.normalize('NFKC', text)
         return self.decoder.decode(ntext)
