@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# vim:fileencoding=utf-8
 
 
 import importlib
@@ -7,14 +6,11 @@ import os
 import sys
 import time
 
-from PyQt5.Qt import QIcon
-from PyQt5.QtWebEngineCore import QWebEngineUrlScheme
+from qt.core import QIcon
 
-from calibre.constants import EDITOR_APP_UID, FAKE_PROTOCOL, islinux
+from calibre.constants import EDITOR_APP_UID, islinux
 from calibre.ebooks.oeb.polish.check.css import shutdown as shutdown_css_check_pool
-from calibre.gui2 import (
-    Application, decouple, set_gui_prefs, setup_gui_option_parser
-)
+from calibre.gui2 import Application, decouple, set_gui_prefs, setup_gui_option_parser
 from calibre.ptempfile import reset_base_dir
 from calibre.utils.config import OptionParser
 
@@ -34,10 +30,11 @@ files inside the book which will be opened for editing automatically.
         )
     )
     setup_gui_option_parser(parser)
+    parser.add_option('--select-text', default=None, help=_('The text to select in the book when it is opened for editing'))
     return parser
 
 
-class EventAccumulator(object):
+class EventAccumulator:
 
     def __init__(self):
         self.events = []
@@ -51,13 +48,11 @@ def gui_main(path=None, notify=None):
 
 
 def _run(args, notify=None):
+    from calibre.utils.webengine import setup_fake_protocol
     # Ensure we can continue to function if GUI is closed
     os.environ.pop('CALIBRE_WORKER_TEMP_DIR', None)
     reset_base_dir()
-    scheme = QWebEngineUrlScheme(FAKE_PROTOCOL.encode('ascii'))
-    scheme.setSyntax(QWebEngineUrlScheme.Syntax.Host)
-    scheme.setFlags(QWebEngineUrlScheme.SecureScheme)
-    QWebEngineUrlScheme.registerScheme(scheme)
+    setup_fake_protocol()
 
     # The following two lines are needed to prevent circular imports causing
     # errors during initialization of plugins that use the polish container
@@ -69,23 +64,25 @@ def _run(args, notify=None):
     parser = option_parser()
     opts, args = parser.parse_args(args)
     decouple('edit-book-'), set_gui_prefs(tprefs)
-    override = 'calibre-edit-book' if islinux else None
+    override = 'calibre-ebook-edit' if islinux else None
     app = Application(args, override_program_name=override, color_prefs=tprefs, windows_app_uid=EDITOR_APP_UID)
+    from calibre.utils.webengine import setup_default_profile
+    setup_default_profile()
     app.file_event_hook = EventAccumulator()
     app.load_builtin_fonts()
-    app.setWindowIcon(QIcon(I('tweak.png')))
+    app.setWindowIcon(QIcon.ic('tweak.png'))
     main = Main(opts, notify=notify)
     main.set_exception_handler()
     main.show()
     app.shutdown_signal_received.connect(main.boss.quit)
     if len(args) > 1:
-        main.boss.open_book(args[1], edit_file=args[2:], clear_notify_data=False)
+        main.boss.open_book(args[1], edit_file=args[2:], clear_notify_data=False, search_text=opts.select_text)
     else:
         for path in reversed(app.file_event_hook.events):
             main.boss.open_book(path)
             break
         app.file_event_hook = main.boss.open_book
-    app.exec_()
+    app.exec()
     # Ensure that the parse worker has quit so that temp files can be deleted
     # on windows
     st = time.time()
